==> v21.04.tar.gz: bookstack/resources/lang/es_AR/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Cancelar',
    'confirm' => 'Confirmar',
    'back' => 'Atrás',
    'save' => 'Guardar',
    'continue' => 'Continuar',
    'select' => 'Seleccionar',
    'toggle_all' => 'Alternar todo',
    'more' => 'Más',

    // Form Labels
    'name' => 'Nombre',
    'description' => 'Descripción',
    'role' => 'Rol',
    'cover_image' => 'Imagen de cubierta',
    'cover_image_description' => 'Esta imagen debe ser de 440x250px aproximadamente.',
    
    // Actions
    'actions' => 'Acciones',
    'view' => 'Ver',
    'view_all' => 'Ver todo',
    'create' => 'Crear',
    'update' => 'Actualizar',
    'edit' => 'Editar',
    'sort' => 'Ordenar',
    'move' => 'Mover',
    'copy' => 'Copiar',
    'reply' => 'Responder',
    'delete' => 'Borrar',
    'delete_confirm' => 'Confirmar eliminación',
    'search' => 'Buscar',
    'search_clear' => 'Limpiar búsqueda',
    'reset' => 'Restablecer',
    'remove' => 'Remover',
    'add' => 'Agregar',
    'fullscreen' => 'Pantalla completa',

    // Sort Options
    'sort_options' => 'Opciones de Orden',
    'sort_direction_toggle' => 'Cambiar Dirección de Orden',
    'sort_ascending' => 'Orden Ascendente',
    'sort_descending' => 'Orden Descendente',
    'sort_name' => 'Nombre',
    'sort_default' => 'Default',
    'sort_created_at' => 'Fecha de creación',
    'sort_updated_at' => 'Fecha de actualización',

    // Misc
    'deleted_user' => 'Usuario borrado',
    'no_activity' => 'Ninguna actividad para mostrar',
    'no_items' => 'No hay items disponibles',
    'back_to_top' => 'Volver arriba',
    'toggle_details' => 'Alternar detalles',
    'toggle_thumbnails' => 'Alternar miniaturas',
    'details' => 'Detalles',
    'grid_view' => 'Vista de grilla',
    'list_view' => 'Vista de lista',
    'default' => 'Por defecto',
    'breadcrumb' => 'Miga de Pan',

    // Header
    'profile_menu' => 'Menu del Perfil',
    'view_profile' => 'Ver Perfil',
    'edit_profile' => 'Editar Perfil',
    'dark_mode' => 'Modo Oscuro',
    'light_mode' => 'Modo Claro',

    // Layout tabs
    'tab_info' => 'Información',
    'tab_content' => 'Contenido',

    // Email Content
    'email_action_help' => 'Si está teniendo problemas haga click en el botón ":actionText", copie y pegue la siguiente URL en su navegador web:',
    'email_rights' => 'Todos los derechos reservados',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Política de privacidad',
    'terms_of_service' => 'Términos de Servicio',
];

==> v21.05.tar.gz: bookstack/resources/lang/es_AR/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Cancelar',
    'confirm' => 'Confirmar',
    'back' => 'Atrás',
    'save' => 'Guardar',
    'continue' => 'Continuar',
    'select' => 'Seleccionar',
    'toggle_all' => 'Alternar todo',
    'more' => 'Más',

    // Form Labels
    'name' => 'Nombre',
    'description' => 'Descripción',
    'role' => 'Rol',
    'cover_image' => 'Imagen de cubierta',
    'cover_image_description' => 'Esta imagen debe ser de 440x250px aproximadamente.',
    
    // Actions
    'actions' => 'Acciones',
    'view' => 'Ver',
    'view_all' => 'Ver todo',
    'create' => 'Crear',
    'update' => 'Actualizar',
    'edit' => 'Editar',
    'sort' => 'Ordenar',
    'move' => 'Mover',
    'copy' => 'Copiar',
    'reply' => 'Responder',
    'delete' => 'Borrar',
    'delete_confirm' => 'Confirmar eliminación',
    'search' => 'Buscar',
    'search_clear' => 'Limpiar búsqueda',
    'reset' => 'Restablecer',
    'remove' => 'Remover',
    'add' => 'Agregar',
    'fullscreen' => 'Pantalla completa',
    'favourite' => 'Añadir a favoritos',
    'unfavourite' => 'Eliminar de favoritos',
    'next' => 'Next',
    'previous' => 'Previous',

    // Sort Options
    'sort_options' => 'Opciones de Orden',
    'sort_direction_toggle' => 'Cambiar Dirección de Orden',
    'sort_ascending' => 'Orden Ascendente',
    'sort_descending' => 'Orden Descendente',
    'sort_name' => 'Nombre',
    'sort_default' => 'Por defecto',
    'sort_created_at' => 'Fecha de creación',
    'sort_updated_at' => 'Fecha de actualización',

    // Misc
    'deleted_user' => 'Usuario borrado',
    'no_activity' => 'Ninguna actividad para mostrar',
    'no_items' => 'No hay items disponibles',
    'back_to_top' => 'Volver arriba',
    'toggle_details' => 'Alternar detalles',
    'toggle_thumbnails' => 'Alternar miniaturas',
    'details' => 'Detalles',
    'grid_view' => 'Vista de grilla',
    'list_view' => 'Vista de lista',
    'default' => 'Por defecto',
    'breadcrumb' => 'Miga de Pan',

    // Header
    'header_menu_expand' => 'Expandir el Menú de Cabecera',
    'profile_menu' => 'Menu del Perfil',
    'view_profile' => 'Ver Perfil',
    'edit_profile' => 'Editar Perfil',
    'dark_mode' => 'Modo Oscuro',
    'light_mode' => 'Modo Claro',

    // Layout tabs
    'tab_info' => 'Información',
    'tab_info_label' => 'Pestaña: Mostrar Información Secundaria',
    'tab_content' => 'Contenido',
    'tab_content_label' => 'Pestaña: Mostrar Contenido Primario',

    // Email Content
    'email_action_help' => 'Si está teniendo problemas haga click en el botón ":actionText", copie y pegue la siguiente URL en su navegador web:',
    'email_rights' => 'Todos los derechos reservados',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Política de privacidad',
    'terms_of_service' => 'Términos de Servicio',
];
